# tdmctl Cli for management of TouDoum-Framework

## Sample of config file
```yaml
current_context: cluster1
context:
    cluster1: 
        host: localhost
        user: admin
        pass: admin
```